# RTLS Platform Services
## Common
### Description
This GitHub repository is a mono repository for building a backend services like `Platform REST API Server`, `Platform Message Processor` and `Solution Platform Sync`.
The repository is organized into three main components:
- `rtls-platform-rest-server`: The web server component that is implementing platform REST API for managing main entities like `nodes`, `tags`, `trackables` etc.
- `rtls-platform-message-processor`: The message processor component is a heart of the server and responsible for processing incoming messages from `rtls--platform-bin-json-convertor`, and `rtls-gateway`. The main responsibilities of message processor is extending raw system messages with platform level information and messages proxying.
- `rtls-platform-sync`: Is the module that is synchronized data between solutions and platform rest servers and databases.

### REST API Documentation
Swagger documentation is accessible by route `api/platform/docs/` 


### Technologies
- `rtls-platform-rest-server`: NodeJs, Express, Redis
- `rtls-platform-message-processo`: Nodejs
- `rtls-platform-sync`: Redis, MariaDb

### Requirements
- Centos 7
- NodeJs v14

### Project local setup
- clone git repository
- install `MariaDB`
- install server node packages `yarn`
- run platform rest server `yarn rs:start`, by default server will run on port 3001
- run platform message processor `yarn mp:start`, by default listen ZMQ 7710 port
- sync `yarn sync:start`, execute synchronization between solution storage and platform storage

## Conventions
### Code style
#### Formatting rules
- please, follow the eslint rules described in project (with this purpose setting up your IDE with the ```.eslintrc```);

#### Naming rules
- please name the variables and constants in a human-readable manner (ex. use `getUsersSql` instead of `sql1`);
- please use the `camelCase` style in name the variables and constants (ex. `getUsersSql` instead of `get_users_sql`);
- please use upper case naming for constants that are not changeable in project (ex. `MAX_ROWS_NUMBER`);
- please use `JavaScript` conventions in naming the classes, constructors(functions) and others entities (classes should be named wih the first capital latter);

### Tests
- run tests coverage with the command `yarn test:coverage` in application directory (`apps/message-processor`, `apps/rest-server`)

#### Unit tests
- unit tests should be places at the same level as the tested file
- unit test name should include the name of the file that is contain covered functionality and obey a pattern `{filename}.test.mjs`
- run tests with the command `yarn test:unit` in application directory (`apps/message-processor`, `apps/rest-server`)
- run tests coverage with the command `yarn test:unit:coverage` in application directory (`apps/message-processor`, `apps/rest-server`)

#### Integration tests
- e2e tests should be places at the `e2e/integration` folder of each application
- e2e test name should include the name of the entity that is testing and obey a pattern `{filename}.test.mjs`
- run tests with the command `yarn test:integration` in application directory (`apps/message-processor`, `apps/rest-server`)
- run tests coverage with the command `yarn test:integration:coverage` in application directory (`apps/message-processor`, `apps/rest-server`)
